# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proio/model/eic/eic.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='proio/model/eic/eic.proto',
  package='proio.model.eic',
  syntax='proto2',
  serialized_options=_b('\n\013proio.modelB\003EicZ\003eic'),
  serialized_pb=_b('\n\x19proio/model/eic/eic.proto\x12\x0fproio.model.eic\"\x81\x02\n\x08Particle\x12\x0e\n\x06parent\x18\x01 \x03(\x04\x12\r\n\x05\x63hild\x18\x02 \x03(\x04\x12\x0b\n\x03pdg\x18\x03 \x01(\x11\x12&\n\x06vertex\x18\x04 \x01(\x0b\x32\x16.proio.model.eic.XYZTD\x12 \n\x01p\x18\t \x01(\x0b\x32\x15.proio.model.eic.XYZF\x12\x0c\n\x04mass\x18\n \x01(\x02\x12\x0e\n\x06\x63harge\x18\x07 \x01(\x02\x12#\n\x04spin\x18\x08 \x01(\x0b\x32\x15.proio.model.eic.XYZF\x12\'\n\x08p_double\x18\x05 \x01(\x0b\x32\x15.proio.model.eic.XYZD\x12\x13\n\x0bmass_double\x18\x06 \x01(\x01\"\x97\x01\n\x06SimHit\x12\x10\n\x08volumeid\x18\x01 \x01(\x04\x12,\n\x0cglobalprepos\x18\x02 \x01(\x0b\x32\x16.proio.model.eic.XYZTD\x12-\n\rglobalpostpos\x18\x03 \x01(\x0b\x32\x16.proio.model.eic.XYZTD\x12\x0c\n\x04\x65\x64\x65p\x18\x04 \x01(\x02\x12\x10\n\x08particle\x18\x05 \x01(\x04\"c\n\tEnergyDep\x12\x0c\n\x04mean\x18\x01 \x01(\x02\x12\r\n\x05noise\x18\x02 \x01(\x02\x12)\n\x03pos\x18\x03 \x03(\x0b\x32\x1c.proio.model.eic.ObservedPos\x12\x0e\n\x06source\x18\x04 \x03(\x04\"L\n\x05Track\x12.\n\x07segment\x18\x01 \x03(\x0b\x32\x1d.proio.model.eic.TrackSegment\x12\x13\n\x0bobservation\x18\x02 \x03(\x04\"\xde\x02\n\x0cTrackSegment\x12&\n\x06vertex\x18\x01 \x01(\x0b\x32\x16.proio.model.eic.XYZTD\x12-\n\x0bvertexnoise\x18\x02 \x03(\x0b\x32\x18.proio.model.eic.RandVar\x12\"\n\x03poq\x18\x03 \x01(\x0b\x32\x15.proio.model.eic.XYZD\x12*\n\x08poqnoise\x18\x04 \x03(\x0b\x32\x18.proio.model.eic.RandVar\x12\'\n\x08magfield\x18\t \x01(\x0b\x32\x15.proio.model.eic.XYZD\x12\x12\n\nchargesign\x18\x07 \x01(\x02\x12\x0e\n\x06length\x18\x08 \x01(\x02\x12(\n\tcurvature\x18\x05 \x01(\x0b\x32\x15.proio.model.eic.XYZD\x12\x30\n\x0e\x63urvaturenoise\x18\x06 \x03(\x0b\x32\x18.proio.model.eic.RandVar\"o\n\x0bObservedPos\x12$\n\x04mean\x18\x01 \x01(\x0b\x32\x16.proio.model.eic.XYZTD\x12\'\n\x05noise\x18\x02 \x03(\x0b\x32\x18.proio.model.eic.RandVar\x12\x11\n\tweightmod\x18\x03 \x01(\x02\"\x8e\x01\n\x07RandVar\x12\x33\n\x04\x64ist\x18\x02 \x01(\x0e\x32%.proio.model.eic.RandVar.Distribution\x12%\n\x05sigma\x18\x03 \x01(\x0b\x32\x16.proio.model.eic.XYZTF\"\'\n\x0c\x44istribution\x12\n\n\x06NORMAL\x10\x00\x12\x0b\n\x07UNIFORM\x10\x01\"3\n\x05XYZTD\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\x12\t\n\x01t\x18\x04 \x01(\x01\"3\n\x05XYZTF\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x12\t\n\x01t\x18\x04 \x01(\x02\"\'\n\x04XYZD\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\"\'\n\x04XYZF\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x42\x17\n\x0bproio.modelB\x03\x45icZ\x03\x65ic')
)



_RANDVAR_DISTRIBUTION = _descriptor.EnumDescriptor(
  name='Distribution',
  full_name='proio.model.eic.RandVar.Distribution',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NORMAL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNIFORM', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1209,
  serialized_end=1248,
)
_sym_db.RegisterEnumDescriptor(_RANDVAR_DISTRIBUTION)


_PARTICLE = _descriptor.Descriptor(
  name='Particle',
  full_name='proio.model.eic.Particle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='proio.model.eic.Particle.parent', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='child', full_name='proio.model.eic.Particle.child', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pdg', full_name='proio.model.eic.Particle.pdg', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertex', full_name='proio.model.eic.Particle.vertex', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p', full_name='proio.model.eic.Particle.p', index=4,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mass', full_name='proio.model.eic.Particle.mass', index=5,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='charge', full_name='proio.model.eic.Particle.charge', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spin', full_name='proio.model.eic.Particle.spin', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p_double', full_name='proio.model.eic.Particle.p_double', index=8,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mass_double', full_name='proio.model.eic.Particle.mass_double', index=9,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47,
  serialized_end=304,
)


_SIMHIT = _descriptor.Descriptor(
  name='SimHit',
  full_name='proio.model.eic.SimHit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='volumeid', full_name='proio.model.eic.SimHit.volumeid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='globalprepos', full_name='proio.model.eic.SimHit.globalprepos', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='globalpostpos', full_name='proio.model.eic.SimHit.globalpostpos', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='edep', full_name='proio.model.eic.SimHit.edep', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='particle', full_name='proio.model.eic.SimHit.particle', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=307,
  serialized_end=458,
)


_ENERGYDEP = _descriptor.Descriptor(
  name='EnergyDep',
  full_name='proio.model.eic.EnergyDep',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mean', full_name='proio.model.eic.EnergyDep.mean', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='noise', full_name='proio.model.eic.EnergyDep.noise', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='proio.model.eic.EnergyDep.pos', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='proio.model.eic.EnergyDep.source', index=3,
      number=4, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=460,
  serialized_end=559,
)


_TRACK = _descriptor.Descriptor(
  name='Track',
  full_name='proio.model.eic.Track',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='segment', full_name='proio.model.eic.Track.segment', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='observation', full_name='proio.model.eic.Track.observation', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=561,
  serialized_end=637,
)


_TRACKSEGMENT = _descriptor.Descriptor(
  name='TrackSegment',
  full_name='proio.model.eic.TrackSegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vertex', full_name='proio.model.eic.TrackSegment.vertex', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertexnoise', full_name='proio.model.eic.TrackSegment.vertexnoise', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='poq', full_name='proio.model.eic.TrackSegment.poq', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='poqnoise', full_name='proio.model.eic.TrackSegment.poqnoise', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='magfield', full_name='proio.model.eic.TrackSegment.magfield', index=4,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chargesign', full_name='proio.model.eic.TrackSegment.chargesign', index=5,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='length', full_name='proio.model.eic.TrackSegment.length', index=6,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='curvature', full_name='proio.model.eic.TrackSegment.curvature', index=7,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='curvaturenoise', full_name='proio.model.eic.TrackSegment.curvaturenoise', index=8,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=640,
  serialized_end=990,
)


_OBSERVEDPOS = _descriptor.Descriptor(
  name='ObservedPos',
  full_name='proio.model.eic.ObservedPos',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mean', full_name='proio.model.eic.ObservedPos.mean', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='noise', full_name='proio.model.eic.ObservedPos.noise', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='weightmod', full_name='proio.model.eic.ObservedPos.weightmod', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=992,
  serialized_end=1103,
)


_RANDVAR = _descriptor.Descriptor(
  name='RandVar',
  full_name='proio.model.eic.RandVar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dist', full_name='proio.model.eic.RandVar.dist', index=0,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sigma', full_name='proio.model.eic.RandVar.sigma', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RANDVAR_DISTRIBUTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1106,
  serialized_end=1248,
)


_XYZTD = _descriptor.Descriptor(
  name='XYZTD',
  full_name='proio.model.eic.XYZTD',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='proio.model.eic.XYZTD.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='proio.model.eic.XYZTD.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z', full_name='proio.model.eic.XYZTD.z', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='t', full_name='proio.model.eic.XYZTD.t', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1250,
  serialized_end=1301,
)


_XYZTF = _descriptor.Descriptor(
  name='XYZTF',
  full_name='proio.model.eic.XYZTF',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='proio.model.eic.XYZTF.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='proio.model.eic.XYZTF.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z', full_name='proio.model.eic.XYZTF.z', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='t', full_name='proio.model.eic.XYZTF.t', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1303,
  serialized_end=1354,
)


_XYZD = _descriptor.Descriptor(
  name='XYZD',
  full_name='proio.model.eic.XYZD',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='proio.model.eic.XYZD.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='proio.model.eic.XYZD.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z', full_name='proio.model.eic.XYZD.z', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1356,
  serialized_end=1395,
)


_XYZF = _descriptor.Descriptor(
  name='XYZF',
  full_name='proio.model.eic.XYZF',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='proio.model.eic.XYZF.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='proio.model.eic.XYZF.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z', full_name='proio.model.eic.XYZF.z', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1397,
  serialized_end=1436,
)

_PARTICLE.fields_by_name['vertex'].message_type = _XYZTD
_PARTICLE.fields_by_name['p'].message_type = _XYZF
_PARTICLE.fields_by_name['spin'].message_type = _XYZF
_PARTICLE.fields_by_name['p_double'].message_type = _XYZD
_SIMHIT.fields_by_name['globalprepos'].message_type = _XYZTD
_SIMHIT.fields_by_name['globalpostpos'].message_type = _XYZTD
_ENERGYDEP.fields_by_name['pos'].message_type = _OBSERVEDPOS
_TRACK.fields_by_name['segment'].message_type = _TRACKSEGMENT
_TRACKSEGMENT.fields_by_name['vertex'].message_type = _XYZTD
_TRACKSEGMENT.fields_by_name['vertexnoise'].message_type = _RANDVAR
_TRACKSEGMENT.fields_by_name['poq'].message_type = _XYZD
_TRACKSEGMENT.fields_by_name['poqnoise'].message_type = _RANDVAR
_TRACKSEGMENT.fields_by_name['magfield'].message_type = _XYZD
_TRACKSEGMENT.fields_by_name['curvature'].message_type = _XYZD
_TRACKSEGMENT.fields_by_name['curvaturenoise'].message_type = _RANDVAR
_OBSERVEDPOS.fields_by_name['mean'].message_type = _XYZTD
_OBSERVEDPOS.fields_by_name['noise'].message_type = _RANDVAR
_RANDVAR.fields_by_name['dist'].enum_type = _RANDVAR_DISTRIBUTION
_RANDVAR.fields_by_name['sigma'].message_type = _XYZTF
_RANDVAR_DISTRIBUTION.containing_type = _RANDVAR
DESCRIPTOR.message_types_by_name['Particle'] = _PARTICLE
DESCRIPTOR.message_types_by_name['SimHit'] = _SIMHIT
DESCRIPTOR.message_types_by_name['EnergyDep'] = _ENERGYDEP
DESCRIPTOR.message_types_by_name['Track'] = _TRACK
DESCRIPTOR.message_types_by_name['TrackSegment'] = _TRACKSEGMENT
DESCRIPTOR.message_types_by_name['ObservedPos'] = _OBSERVEDPOS
DESCRIPTOR.message_types_by_name['RandVar'] = _RANDVAR
DESCRIPTOR.message_types_by_name['XYZTD'] = _XYZTD
DESCRIPTOR.message_types_by_name['XYZTF'] = _XYZTF
DESCRIPTOR.message_types_by_name['XYZD'] = _XYZD
DESCRIPTOR.message_types_by_name['XYZF'] = _XYZF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Particle = _reflection.GeneratedProtocolMessageType('Particle', (_message.Message,), dict(
  DESCRIPTOR = _PARTICLE,
  __module__ = 'proio.model.eic.eic_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.eic.Particle)
  ))
_sym_db.RegisterMessage(Particle)

SimHit = _reflection.GeneratedProtocolMessageType('SimHit', (_message.Message,), dict(
  DESCRIPTOR = _SIMHIT,
  __module__ = 'proio.model.eic.eic_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.eic.SimHit)
  ))
_sym_db.RegisterMessage(SimHit)

EnergyDep = _reflection.GeneratedProtocolMessageType('EnergyDep', (_message.Message,), dict(
  DESCRIPTOR = _ENERGYDEP,
  __module__ = 'proio.model.eic.eic_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.eic.EnergyDep)
  ))
_sym_db.RegisterMessage(EnergyDep)

Track = _reflection.GeneratedProtocolMessageType('Track', (_message.Message,), dict(
  DESCRIPTOR = _TRACK,
  __module__ = 'proio.model.eic.eic_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.eic.Track)
  ))
_sym_db.RegisterMessage(Track)

TrackSegment = _reflection.GeneratedProtocolMessageType('TrackSegment', (_message.Message,), dict(
  DESCRIPTOR = _TRACKSEGMENT,
  __module__ = 'proio.model.eic.eic_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.eic.TrackSegment)
  ))
_sym_db.RegisterMessage(TrackSegment)

ObservedPos = _reflection.GeneratedProtocolMessageType('ObservedPos', (_message.Message,), dict(
  DESCRIPTOR = _OBSERVEDPOS,
  __module__ = 'proio.model.eic.eic_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.eic.ObservedPos)
  ))
_sym_db.RegisterMessage(ObservedPos)

RandVar = _reflection.GeneratedProtocolMessageType('RandVar', (_message.Message,), dict(
  DESCRIPTOR = _RANDVAR,
  __module__ = 'proio.model.eic.eic_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.eic.RandVar)
  ))
_sym_db.RegisterMessage(RandVar)

XYZTD = _reflection.GeneratedProtocolMessageType('XYZTD', (_message.Message,), dict(
  DESCRIPTOR = _XYZTD,
  __module__ = 'proio.model.eic.eic_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.eic.XYZTD)
  ))
_sym_db.RegisterMessage(XYZTD)

XYZTF = _reflection.GeneratedProtocolMessageType('XYZTF', (_message.Message,), dict(
  DESCRIPTOR = _XYZTF,
  __module__ = 'proio.model.eic.eic_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.eic.XYZTF)
  ))
_sym_db.RegisterMessage(XYZTF)

XYZD = _reflection.GeneratedProtocolMessageType('XYZD', (_message.Message,), dict(
  DESCRIPTOR = _XYZD,
  __module__ = 'proio.model.eic.eic_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.eic.XYZD)
  ))
_sym_db.RegisterMessage(XYZD)

XYZF = _reflection.GeneratedProtocolMessageType('XYZF', (_message.Message,), dict(
  DESCRIPTOR = _XYZF,
  __module__ = 'proio.model.eic.eic_pb2'
  # @@protoc_insertion_point(class_scope:proio.model.eic.XYZF)
  ))
_sym_db.RegisterMessage(XYZF)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import io
import pytest

import google.protobuf.descriptor_pb2 as descriptor_pb2

import proio
import proio.model.lcio as prolcio

def test_push_get1_lz4():
    push_get1(proio.LZ4)

def test_push_get2_lz4():
    push_get2(proio.LZ4)

def test_push_get3_lz4():
    push_get3(proio.LZ4)

def test_push_get4_lz4():
    push_get4(proio.LZ4)

def test_push_skip_get1_lz4():
    push_skip_get1(proio.LZ4)

def test_push_skip_get2_lz4():
    push_skip_get2(proio.LZ4)

def test_push_seek_skip_get1_lz4():
    push_seek_skip_get1(proio.LZ4)

def test_push_get1_gzip():
    push_get1(proio.GZIP)

def test_push_get2_gzip():
    push_get2(proio.GZIP)

def test_push_get3_gzip():
    push_get3(proio.GZIP)

def test_push_get4_gzip():
    push_get4(proio.GZIP)

def test_push_skip_get1_gzip():
    push_skip_get1(proio.GZIP)

def test_push_skip_get2_gzip():
    push_skip_get2(proio.GZIP)

def test_push_seek_skip_get1_gzip():
    push_seek_skip_get1(proio.GZIP)

def test_push_get1_uncompressed():
    push_get1(proio.UNCOMPRESSED)

def test_push_get2_uncompressed():
    push_get2(proio.UNCOMPRESSED)

def test_push_get3_uncompressed():
    push_get3(proio.UNCOMPRESSED)

def test_push_get4_uncompressed():
    push_get4(proio.UNCOMPRESSED)

def test_push_skip_get1_uncompressed():
    push_skip_get1(proio.UNCOMPRESSED)

def test_push_skip_get2_uncompressed():
    push_skip_get2(proio.UNCOMPRESSED)

def test_push_seek_skip_get1_uncompressed():
    push_seek_skip_get1(proio.UNCOMPRESSED)

def push_get1(comp):
    buf = io.BytesIO(b'')
    with proio.Writer(fileobj = buf) as writer:
        writer.set_compression(comp)

        eventsOut = []

        event = proio.Event()
        event.add_entries(
                'MCParticle',
                prolcio.MCParticle(),
                prolcio.MCParticle()
                )
        event.add_entries(
                'TrackerHits',
                prolcio.SimTrackerHit(),
                prolcio.SimTrackerHit()
                )
        writer.push(event)
        eventsOut.append(event)
        
        event = proio.Event()
        event.add_entries(
                'TrackerHits',
                prolcio.SimTrackerHit(),
                prolcio.SimTrackerHit()
                )
        writer.push(event)
        eventsOut.append(event)

    buf.seek(0, 0)

    with proio.Reader(fileobj = buf) as reader:
        for i in range(0, len(eventsOut)):
            event = reader.__next__()
            assert event != None
            assert event.__str__() == eventsOut[i].__str__()

def push_get2(comp):
    buf = io.BytesIO(b'')
    with proio.Writer(fileobj = buf) as writer:
        writer.set_compression(comp)

        eventsOut = []

        event = proio.Event()
        event.add_entries(
                'MCParticle',
                prolcio.MCParticle(),
                prolcio.MCParticle()
                )
        event.add_entries(
                'TrackerHits',
                prolcio.SimTrackerHit(),
                prolcio.SimTrackerHit()
                )
        writer.push(event)
        eventsOut.append(event)
        writer.flush()
        
        event = proio.Event()
        event.add_entries(
                'TrackerHits',
                prolcio.SimTrackerHit(),
                prolcio.SimTrackerHit()
                )
        writer.push(event)
        eventsOut.append(event)

    buf.seek(0, 0)

    with proio.Reader(fileobj = buf) as reader:
        for i in range(0, len(eventsOut)):
            event = reader.__next__()
            assert event != None
            assert event.__str__() == eventsOut[i].__str__()

def push_get3(comp):
    buf = io.BytesIO(b'')
    with proio.Writer(fileobj = buf) as writer:
        writer.set_compression(comp)

        event = proio.Event()
        event.add_entries(
                'MCParticle',
                prolcio.MCParticle(),
                prolcio.MCParticle()
                )
        event.add_entries(
                'TrackerHits',
                prolcio.SimTrackerHit(),
                prolcio.SimTrackerHit()
                )
        writer.push(event)
        
        event = proio.Event()
        event.add_entry(
                'TrackerHits',
                prolcio.SimTrackerHit(),
                )
        writer.push(event)

    buf.seek(0, 0)
    buf2 = io.BytesIO(b'')

    with proio.Reader(fileobj = buf) as reader:
        with proio.Writer(fileobj = buf2) as writer:
            eventsOut = []
            for event in reader:
                event.add_entry(
                        'TrackerHits',
                        prolcio.SimTrackerHit(),
                        )
                eventsOut.append(event)
                writer.push(event)

    buf2.seek(0, 0)

    with proio.Reader(fileobj = buf2) as reader:
        for i in range(0, len(eventsOut)):
            event = reader.__next__()
            assert event != None
            assert event.__str__() == eventsOut[i].__str__()

def push_get4(comp):
    buf = io.BytesIO(b'')
    with proio.Writer(fileobj = buf) as writer:
        writer.set_compression(comp)

        eventsOut = []

        event = proio.Event()
        event.add_entry('test', descriptor_pb2.FileDescriptorProto())
        writer.push(event)
        eventsOut.append(event)

    buf.seek(0, 0)

    with proio.Reader(fileobj = buf) as reader:
        for i in range(0, len(eventsOut)):
            event = reader.__next__()
            assert event != None
            assert event.__str__() == eventsOut[i].__str__()

def push_skip_get1(comp):
    buf = io.BytesIO(b'')
    with proio.Writer(fileobj = buf) as writer:
        writer.set_compression(comp)

        eventsOut = []

        event = proio.Event()
        event.add_entries(
                'MCParticle',
                prolcio.MCParticle(),
                prolcio.MCParticle()
                )
        event.add_entries(
                'TrackerHits',
                prolcio.SimTrackerHit(),
                prolcio.SimTrackerHit()
                )
        writer.push(event)
        eventsOut.append(event)
        
        event = proio.Event()
        event.add_entries(
                'TrackerHits',
                prolcio.SimTrackerHit(),
                prolcio.SimTrackerHit()
                )
        writer.push(event)
        eventsOut.append(event)

    buf.seek(0, 0)

    with proio.Reader(fileobj = buf) as reader:
        reader.skip(1)
        event = reader.__next__()
        assert event != None
        assert event.__str__() == eventsOut[1].__str__()

def push_skip_get2(comp):
    buf = io.BytesIO(b'')
    with proio.Writer(fileobj = buf) as writer:
        writer.set_compression(comp)

        eventsOut = []

        event = proio.Event()
        event.add_entries(
                'MCParticle',
                prolcio.MCParticle(),
                prolcio.MCParticle()
                )
        event.add_entries(
                'TrackerHits',
                prolcio.SimTrackerHit(),
                prolcio.SimTrackerHit()
                )
        writer.push(event)
        eventsOut.append(event)
        writer.flush()
        
        event = proio.Event()
        event.add_entries(
                'TrackerHits',
                prolcio.SimTrackerHit(),
                prolcio.SimTrackerHit()
                )
        writer.push(event)
        eventsOut.append(event)

    buf.seek(0, 0)

    with proio.Reader(fileobj = buf) as reader:
        reader.skip(1)
        event = reader.__next__()
        assert event != None
        assert event.__str__() == eventsOut[1].__str__()

def push_seek_skip_get1(comp):
    buf = io.BytesIO(b'')
    with proio.Writer(fileobj = buf) as writer:
        writer.set_compression(comp)

        eventsOut = []

        event = proio.Event()
        event.add_entries(
                'Hit1',
                prolcio.MCParticle(),
                prolcio.MCParticle()
                )
        writer.push(event)
        eventsOut.append(event)
        
        event = proio.Event()
        event.add_entries(
                'Hit2',
                prolcio.SimTrackerHit(),
                prolcio.SimTrackerHit()
                )
        writer.push(event)
        eventsOut.append(event)

        writer.flush()

        event = proio.Event()
        event.add_entries(
                'Hit3',
                prolcio.SimTrackerHit(),
                prolcio.SimTrackerHit()
                )
        writer.push(event)
        eventsOut.append(event)

    buf.seek(0, 0)

    with proio.Reader(fileobj = buf) as reader:
        event = reader.__next__()
        assert event != None
        assert event.__str__() == eventsOut[0].__str__()

        reader.seek_to_start()
        reader.skip(2)
        event = reader.__next__()
        assert event != None
        assert event.__str__() == eventsOut[2].__str__()




import proio.proto as proto

import google.protobuf.descriptor_pool as descriptor_pool
import google.protobuf.message_factory as message_factory

class Event(object):
    """
    Class representing a single event
    """

    def __init__(self, proto_obj = None):
        self.metadata = {}

        self._proto = proto_obj or proto.Event()
        self._entry_cache = {}
        self._factory = message_factory.MessageFactory()
        self._rev_type_lookup = {}
        self._dirty_tags = False

    def add_entry(self, tag, entry):
        """
        takes a tag and protobuf message entry and adds it to the Event.  The
        return value is an integer ID number used to reference the added entry.

        :param string tag: tag
        :param Message entry: entry
        :return: identifier for entry
        :rtype: int
        """
        type_id = self._get_type_id(entry)

        self._proto.nEntries += 1
        ID = self._proto.nEntries
        self._proto.entry[ID].type = type_id

        self._entry_cache[ID] = entry

        self.tag_entry(ID, tag)

        return ID

    def add_entries(self, tag, *entries):
        """
        is like :func:`add_entry`, except that it takes any number of entries,
        and returns a list of corresponding IDs.

        :param string tag: tag
        :param Message \*entries: entries
        :return: identifiers for entry
        :rtype: int list
        """
        ids = []
        for entry in entries:
            ids.append(self.add_entry(tag, entry))
        return ids

    def get_entry(self, ID):
        """
        takes an entry ID and returns the corresponding entry.  Returns None if
        the entry does not exist.

        :param int ID: identifier for entry
        :return: entry message object
        :rtype: :class:`google.protobuf.message.Message`
        """
        if ID in self._entry_cache:
            return self._entry_cache[ID]
        if ID in self._proto.entry:
            entry_proto = self._proto.entry[ID]
        else:
            return None

        type_string = self._proto.type[entry_proto.type]
        try:
            type_desc = descriptor_pool.Default().FindMessageTypeByName(type_string)
        except KeyError:
            type_desc = None
        if type_desc is None:
            raise UnknownTypeError(type_string)
        msg_class = self._factory.GetPrototype(type_desc)
        entry = msg_class.FromString(entry_proto.payload)
        self._entry_cache[ID] = entry

        return entry

    def remove_entry(self, ID):
        """
        removes an entry from the event by its entry ID.

        :param int ID: identifier for entry
        """
        self._entry_cache.pop(ID, None)
        self._proto.entry.pop(ID, None)
        self._dirty_tags = True

    def tag_entry(self, ID, *tags):
        """
        adds tags to an entry identified by ID.

        :param int ID: identifier for entry
        :param string \*tags: tags
        """
        for tag in tags:
            tag_proto = self._proto.tag[tag]
            tag_proto.entry.append(ID)

    def untag_entry(self, ID, tag):
        """
        removes the specified tag from the entry ID

        :param int ID: identifier for entry
        :param string tag: tag
        """
        if tag in self._proto.tag:
            try:
                self._proto.tag[tag].entry.remove(ID)
            except ValueError:
                pass

    def tags(self):
        """
        returns a list of tags that exist in the event.

        :return: list of strings
        """
        tags = list(self._proto.tag.keys())
        tags.sort()
        return tags

    def entry_tags(self, ID):
        """
        returns a list of tags that point to a given entry ID.

        :param int ID: identifier for entry
        :return: list of strings
        """
        tags = []
        for tag, value in self._proto.tag.items():
            if ID in value.entry:
                tags.append(tag)
        return tags

    def tagged_entries(self, tag):
        """
        takes a tag string and returns a list of entry IDs that the tag
        references.

        :param string tag: tag
        :return: identifiers for entries
        :rtype: int list
        """
        self._tag_cleanup()
        return list(self._proto.tag[tag].entry)

    def all_entries(self):
        """
        returns a list of entry IDs for the event.

        :return: identifiers for entries
        :rtype: int list
        """
        return list(self._proto.entry.keys())

    def delete_tag(self, tag):
        """
        removes the tag that matches the given tag string from the event.

        :param string tag: tag
        """
        self._proto.tag.pop(tag, None)

    def _get_type_id(self, entry):
        type_name = entry.DESCRIPTOR.full_name
        try:
            return self._rev_type_lookup[type_name]
        except KeyError:
            for ID, name in self._proto.type.items():
                if name == type_name:
                    self._rev_type_lookup[name] = ID
                    return ID

            self._proto.nTypes += 1
            type_id = self._proto.nTypes
            self._proto.type[type_id] = type_name
            self._rev_type_lookup[type_name] = type_id

            return type_id

    def _flush_cache(self):
        for ID, entry in self._entry_cache.items():
            self._proto.entry[ID].payload = entry.SerializeToString()
        self._entry_cache = {}
        self._tag_cleanup()

    def __str__(self):
        print_string = ''

        tags = self.tags()
        for tag in tags:
            print_string += '---------- TAG: ' + tag + ' ----------\n'
            entries = self.tagged_entries(tag)
            for entry_id in entries:
                print_string += 'ID: %i\n' % entry_id
                entry = self.get_entry(entry_id)
                if entry is not None:
                    print_string += 'Entry type: ' + entry.DESCRIPTOR.full_name + '\n'
                    print_string += '%s\n' % entry
                else:
                    print_string += 'not found'

        return print_string

    def _tag_cleanup(self):
        if not self._dirty_tags:
            return
        for tag in self._proto.tag.values():
            tag.entry[:] = [ID for ID in tag.entry if ID in self._proto.entry]
        self._dirty_tags = False

class UnknownTypeError(Exception):
    """
    Raised when an Event object is unable to deserialize a particular entry
    type.
    """
    pass



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proio/proto/proio.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='proio/proto/proio.proto',
  package='proio.proto',
  syntax='proto3',
  serialized_options=_b('\n\005proioB\005ProtoZ\005proto'),
  serialized_pb=_b('\n\x17proio/proto/proio.proto\x12\x0bproio.proto\"\xaf\x02\n\x0c\x42ucketHeader\x12\x0f\n\x07nEvents\x18\x01 \x01(\x04\x12\x12\n\nbucketSize\x18\x02 \x01(\x04\x12\x37\n\x0b\x63ompression\x18\x03 \x01(\x0e\x32\".proio.proto.BucketHeader.CompType\x12\x16\n\x0e\x66ileDescriptor\x18\x05 \x03(\x0c\x12\x39\n\x08metadata\x18\x07 \x03(\x0b\x32\'.proio.proto.BucketHeader.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"1\n\x08\x43ompType\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04GZIP\x10\x01\x12\x07\n\x03LZ4\x10\x02\x12\x08\n\x04LZMA\x10\x03J\x04\x08\x04\x10\x05J\x04\x08\x06\x10\x07\"\xd8\x02\n\x05\x45vent\x12(\n\x03tag\x18\x01 \x03(\x0b\x32\x1b.proio.proto.Event.TagEntry\x12\x10\n\x08nEntries\x18\x02 \x01(\x04\x12,\n\x05\x65ntry\x18\x03 \x03(\x0b\x32\x1d.proio.proto.Event.EntryEntry\x12\x0e\n\x06nTypes\x18\x04 \x01(\x04\x12*\n\x04type\x18\x05 \x03(\x0b\x32\x1c.proio.proto.Event.TypeEntry\x1a<\n\x08TagEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.proio.proto.Tag:\x02\x38\x01\x1a>\n\nEntryEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.proio.proto.Any:\x02\x38\x01\x1a+\n\tTypeEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x14\n\x03Tag\x12\r\n\x05\x65ntry\x18\x01 \x03(\x04\"$\n\x03\x41ny\x12\x0c\n\x04type\x18\x01 \x01(\x04\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x42\x15\n\x05proioB\x05ProtoZ\x05protob\x06proto3')
)



_BUCKETHEADER_COMPTYPE = _descriptor.EnumDescriptor(
  name='CompType',
  full_name='proio.proto.BucketHeader.CompType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GZIP', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LZ4', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LZMA', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=283,
  serialized_end=332,
)
_sym_db.RegisterEnumDescriptor(_BUCKETHEADER_COMPTYPE)


_BUCKETHEADER_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='proio.proto.BucketHeader.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='proio.proto.BucketHeader.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='proio.proto.BucketHeader.MetadataEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=234,
  serialized_end=281,
)

_BUCKETHEADER = _descriptor.Descriptor(
  name='BucketHeader',
  full_name='proio.proto.BucketHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nEvents', full_name='proio.proto.BucketHeader.nEvents', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bucketSize', full_name='proio.proto.BucketHeader.bucketSize', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compression', full_name='proio.proto.BucketHeader.compression', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fileDescriptor', full_name='proio.proto.BucketHeader.fileDescriptor', index=3,
      number=5, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='proio.proto.BucketHeader.metadata', index=4,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_BUCKETHEADER_METADATAENTRY, ],
  enum_types=[
    _BUCKETHEADER_COMPTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41,
  serialized_end=344,
)


_EVENT_TAGENTRY = _descriptor.Descriptor(
  name='TagEntry',
  full_name='proio.proto.Event.TagEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='proio.proto.Event.TagEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='proio.proto.Event.TagEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=522,
  serialized_end=582,
)

_EVENT_ENTRYENTRY = _descriptor.Descriptor(
  name='EntryEntry',
  full_name='proio.proto.Event.EntryEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='proio.proto.Event.EntryEntry.key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='proio.proto.Event.EntryEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=584,
  serialized_end=646,
)

_EVENT_TYPEENTRY = _descriptor.Descriptor(
  name='TypeEntry',
  full_name='proio.proto.Event.TypeEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='proio.proto.Event.TypeEntry.key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='proio.proto.Event.TypeEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=648,
  serialized_end=691,
)

_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='proio.proto.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='proio.proto.Event.tag', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nEntries', full_name='proio.proto.Event.nEntries', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entry', full_name='proio.proto.Event.entry', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nTypes', full_name='proio.proto.Event.nTypes', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='proio.proto.Event.type', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_EVENT_TAGENTRY, _EVENT_ENTRYENTRY, _EVENT_TYPEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=347,
  serialized_end=691,
)


_TAG = _descriptor.Descriptor(
  name='Tag',
  full_name='proio.proto.Tag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entry', full_name='proio.proto.Tag.entry', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=693,
  serialized_end=713,
)


_ANY = _descriptor.Descriptor(
  name='Any',
  full_name='proio.proto.Any',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='proio.proto.Any.type', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='proio.proto.Any.payload', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=715,
  serialized_end=751,
)

_BUCKETHEADER_METADATAENTRY.containing_type = _BUCKETHEADER
_BUCKETHEADER.fields_by_name['compression'].enum_type = _BUCKETHEADER_COMPTYPE
_BUCKETHEADER.fields_by_name['metadata'].message_type = _BUCKETHEADER_METADATAENTRY
_BUCKETHEADER_COMPTYPE.containing_type = _BUCKETHEADER
_EVENT_TAGENTRY.fields_by_name['value'].message_type = _TAG
_EVENT_TAGENTRY.containing_type = _EVENT
_EVENT_ENTRYENTRY.fields_by_name['value'].message_type = _ANY
_EVENT_ENTRYENTRY.containing_type = _EVENT
_EVENT_TYPEENTRY.containing_type = _EVENT
_EVENT.fields_by_name['tag'].message_type = _EVENT_TAGENTRY
_EVENT.fields_by_name['entry'].message_type = _EVENT_ENTRYENTRY
_EVENT.fields_by_name['type'].message_type = _EVENT_TYPEENTRY
DESCRIPTOR.message_types_by_name['BucketHeader'] = _BUCKETHEADER
DESCRIPTOR.message_types_by_name['Event'] = _EVENT
DESCRIPTOR.message_types_by_name['Tag'] = _TAG
DESCRIPTOR.message_types_by_name['Any'] = _ANY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BucketHeader = _reflection.GeneratedProtocolMessageType('BucketHeader', (_message.Message,), dict(

  MetadataEntry = _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), dict(
    DESCRIPTOR = _BUCKETHEADER_METADATAENTRY,
    __module__ = 'proio.proto.proio_pb2'
    # @@protoc_insertion_point(class_scope:proio.proto.BucketHeader.MetadataEntry)
    ))
  ,
  DESCRIPTOR = _BUCKETHEADER,
  __module__ = 'proio.proto.proio_pb2'
  # @@protoc_insertion_point(class_scope:proio.proto.BucketHeader)
  ))
_sym_db.RegisterMessage(BucketHeader)
_sym_db.RegisterMessage(BucketHeader.MetadataEntry)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), dict(

  TagEntry = _reflection.GeneratedProtocolMessageType('TagEntry', (_message.Message,), dict(
    DESCRIPTOR = _EVENT_TAGENTRY,
    __module__ = 'proio.proto.proio_pb2'
    # @@protoc_insertion_point(class_scope:proio.proto.Event.TagEntry)
    ))
  ,

  EntryEntry = _reflection.GeneratedProtocolMessageType('EntryEntry', (_message.Message,), dict(
    DESCRIPTOR = _EVENT_ENTRYENTRY,
    __module__ = 'proio.proto.proio_pb2'
    # @@protoc_insertion_point(class_scope:proio.proto.Event.EntryEntry)
    ))
  ,

  TypeEntry = _reflection.GeneratedProtocolMessageType('TypeEntry', (_message.Message,), dict(
    DESCRIPTOR = _EVENT_TYPEENTRY,
    __module__ = 'proio.proto.proio_pb2'
    # @@protoc_insertion_point(class_scope:proio.proto.Event.TypeEntry)
    ))
  ,
  DESCRIPTOR = _EVENT,
  __module__ = 'proio.proto.proio_pb2'
  # @@protoc_insertion_point(class_scope:proio.proto.Event)
  ))
_sym_db.RegisterMessage(Event)
_sym_db.RegisterMessage(Event.TagEntry)
_sym_db.RegisterMessage(Event.EntryEntry)
_sym_db.RegisterMessage(Event.TypeEntry)

Tag = _reflection.GeneratedProtocolMessageType('Tag', (_message.Message,), dict(
  DESCRIPTOR = _TAG,
  __module__ = 'proio.proto.proio_pb2'
  # @@protoc_insertion_point(class_scope:proio.proto.Tag)
  ))
_sym_db.RegisterMessage(Tag)

Any = _reflection.GeneratedProtocolMessageType('Any', (_message.Message,), dict(
  DESCRIPTOR = _ANY,
  __module__ = 'proio.proto.proio_pb2'
  # @@protoc_insertion_point(class_scope:proio.proto.Any)
  ))
_sym_db.RegisterMessage(Any)


DESCRIPTOR._options = None
_BUCKETHEADER_METADATAENTRY._options = None
_EVENT_TAGENTRY._options = None
_EVENT_ENTRYENTRY._options = None
_EVENT_TYPEENTRY._options = None
# @@protoc_insertion_point(module_scope)



import glob
import os
import setuptools
import shutil
import subprocess
import sys

from distutils.command.clean import clean as _clean
from distutils.spawn import find_executable
from os.path import basename
from os.path import splitext

if sys.version_info[0] == 3:
    from distutils.command.build_py import build_py_2to3 as _build_py
else:
    from distutils.command.build_py import build_py as _build_py

models = [basename(model) for model in glob.glob('proto/model/*')]

protoc = find_executable('protoc')

def generate_main_proto():
    main_proto_path = 'proio/proto/proio_pb2.py'
    if os.path.exists(main_proto_path):
        return

    if protoc is None:
        print('protoc not found')
        sys.exit(1)

    protoc_command = [
    protoc,
        '--proto_path=proio/proto=proto',
        '--python_out=.',
        'proto/proio.proto',
        ]
    if subprocess.call(protoc_command) != 0:
        print('failed to call protoc for proio.proto')
        sys.exit(1)

def generate_model_proto(model):
    if os.path.exists('proio/model/' + model):
        return

    os.mkdir('proio/model/' + model)

    with open('proio/model/' + model + '/__init__.py', 'w') as init_file:
        for file in glob.glob('proto/model/%s/*.proto' % model):
            protoc_command = [
                    protoc,
                    '--proto_path=proio/model=proto/model'
                    ,'--python_out=.',
                    file,
                    ]
            if subprocess.call(protoc_command) != 0:
                print('failed to call protoc for file: ' + file)
                sys.exit(1)
            init_file.write('from .%s_pb2 import *\n' % splitext(basename(file))[0])

class clean(_clean):
    def run(self):
        try:
            os.remove('proio/proto/proio_pb2.py')
        except OSError:
            pass

        for model in models:
            shutil.rmtree('proio/model/' + model, ignore_errors=True)

        _clean.run(self);

class build_py(_build_py):
    def run(self):
        generate_main_proto()

        for model in models:
            generate_model_proto(model)

        _build_py.run(self)

setuptools.setup(
        name = 'proio',
        version = '0.12.49',
        description = 'Library for reading and writing proio files and streams',
        url = 'http://github.com/proio-org/py-proio',
        author = 'David Blyth',
        author_email = 'dblyth@anl.gov',
        license = 'BSD-3-Clause',
        packages = setuptools.find_packages(),
        install_requires = ['protobuf>=3.6.1', 'lz4==2.*'],
        zip_safe = True,
        cmdclass = {
            'clean': clean,
            'build_py' : build_py,
            }
      )
